==> geant4.9.5.p02.tar.gz: geant4.9.5.p02/source/processes/hadronic/models/inclxx/incl_physics/src/G4INCLPropagationAction.cc <==
//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
// INCL++ intra-nuclear cascade model
// Pekka Kaitaniemi, CEA and Helsinki Institute of Physics
// Davide Mancusi, CEA
// Alain Boudard, CEA
// Sylvie Leray, CEA
// Joseph Cugnon, University of Liege
//
// INCL++ revision: v5.0_rc3
//
#define INCLXX_IN_GEANT4_MODE 1

#include "globals.hh"

#include "G4INCLPropagationAction.hh"
#include "G4INCLLogger.hh"
//#include <cassert>

namespace G4INCL {

  PropagationAction::PropagationAction()
    :stepCounter(0)
  {

  }

  PropagationAction::~PropagationAction() {
  }

  void PropagationAction::beforePropagationAction(IPropagationModel * /*pm*/) {
    // assert(pm->getNucleus()->getStore()->getBook()->getParticipants() == pm->getNucleus()->getStore()->countParticipants());
  }

  void PropagationAction::afterPropagationAction(IPropagationModel * /* pm */,
						 IAvatar * /*avatar */) {
    ++stepCounter; // Increment the step counter

#ifdef INCL_DEBUG_LOG
    //   DATABLOCK(pm->getNucleus()->getStore()->prG4intParticleConfiguration());
#endif
  }
}

==> geant4.9.6.p03.tar.gz: geant4.9.6.p03/source/processes/hadronic/models/inclxx/incl_physics/src/G4INCLPropagationAction.cc <==
//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
// INCL++ intra-nuclear cascade model
// Pekka Kaitaniemi, CEA and Helsinki Institute of Physics
// Davide Mancusi, CEA
// Alain Boudard, CEA
// Sylvie Leray, CEA
// Joseph Cugnon, University of Liege
//
#define INCLXX_IN_GEANT4_MODE 1

#include "globals.hh"

#include "G4INCLPropagationAction.hh"
#include "G4INCLLogger.hh"
// #include <cassert>

namespace G4INCL {

  PropagationAction::PropagationAction()
    :stepCounter(0)
  {

  }

  PropagationAction::~PropagationAction() {
  }

  void PropagationAction::beforePropagationAction(IPropagationModel * /*pm*/) {
    // assert(pm->getNucleus()->getStore()->getBook()->getCascading() == pm->getNucleus()->getStore()->countCascading());
  }

  void PropagationAction::afterPropagationAction(IPropagationModel * /* pm */,
						 IAvatar * /*avatar */) {
    ++stepCounter; // Increment the step counter

#ifdef INCL_DEBUG_LOG
    //   DATABLOCK(pm->getNucleus()->getStore()->printParticleConfiguration());
#endif
  }
}
